/* Formatted on 2005/03/28 09:48 (Formatter Plus v4.8.5) */
CREATE OR REPLACE PACKAGE BODY hum_xml
IS
   PROCEDURE checkxmlinclob (
      c                                   CLOB
,     wellformed                 OUT      BOOLEAN
,     error                      OUT      VARCHAR2
   )
   IS
      parser                        DBMS_XMLPARSER.parser;
      l_step                        VARCHAR2 (100);
      xmldoc                        DBMS_XMLDOM.domdocument;
      xmlparseerror                 EXCEPTION;
      -- Associate the XMLParseError exception with the -20100 error code
      PRAGMA EXCEPTION_INIT (xmlparseerror, -20100);
   BEGIN
--
--       l_step                     := 'STEP1 :: CHECKXMLINCLOB';
--       -- (1) Create a new parser
--       parser                     := DBMS_XMLPARSER.newparser;
--       l_step                     := 'STEP2 :: CHECKXMLINCLOB';
--       -- (2) Attempt to parse the XML document in the CLOB
--       DBMS_XMLPARSER.parseclob (parser, c);
--       l_step                     := 'STEP3 :: CHECKXMLINCLOB';
--       -- (3) Free the parser.
--       DBMS_XMLPARSER.freeparser (parser);
--       l_step                     := 'STEP4 :: CHECKXMLINCLOB';
--       -- If the parse succeeds, we'll get here
      wellformed                 := TRUE;
      l_step                     := 'STEP5 :: CHECKXMLINCLOB';
   EXCEPTION
      -- If the parse fails, we'll jump here.
      WHEN xmlparseerror
      THEN
         DBMS_XMLPARSER.freeparser (parser);
         wellformed                 := FALSE;
         error                      :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
   END checkxmlinclob;

   FUNCTION dump_xml (
      p_query                    IN       VARCHAR2
,     p_dir                      IN       VARCHAR2
,     p_filename                 IN       VARCHAR2
,     p_max_linesize             IN       NUMBER DEFAULT 32000
,     p_mode                     IN       VARCHAR2 DEFAULT 'w'
   )
      RETURN NUMBER
   IS
      l_output                      UTL_FILE.file_type;
      l_thecursor                   INTEGER DEFAULT DBMS_SQL.open_cursor;
      l_columnvalue                 VARCHAR2 (4000);
      l_status                      INTEGER;
      l_colcnt                      NUMBER DEFAULT 0;
      l_colcnt_array                humcust.hum_toolbox.vc80_table;
      l_colcnt_empty_array          humcust.hum_toolbox.vc80_table;
      l_cnt                         NUMBER DEFAULT 0;
      l_separator                   VARCHAR2 (10) DEFAULT '';
      l_line                        LONG;
      l_desctbl                     DBMS_SQL.desc_tab;
      v_sqlerrm                     VARCHAR2 (32000);
      l_mode                        CHAR (1) := 'w';
   BEGIN
      l_colcnt_array             := l_colcnt_empty_array;

      IF p_mode NOT IN ('w', 'a')
      THEN
         l_mode                     := 'w';
      ELSE
         l_mode                     := p_mode;
      END IF;

      l_output                   :=
                    UTL_FILE.fopen (p_dir
,                                   p_filename
,                                   l_mode
,                                   p_max_linesize
                                   );
      DBMS_SQL.parse (l_thecursor
,                     p_query
,                     DBMS_SQL.native
                     );
      DBMS_SQL.describe_columns (l_thecursor
,                                l_colcnt
,                                l_desctbl
                                );

      FOR i IN 1 .. l_colcnt
      LOOP
         DBMS_SQL.define_column (l_thecursor
,                                i
,                                l_columnvalue
,                                4000
                                );

         IF (l_desctbl (i).col_type = 2)                     /* number type */
         THEN
            l_desctbl (i).col_max_len  :=   l_desctbl (i).col_precision
                                          + 2;
         ELSIF (l_desctbl (i).col_type = 12)                   /* date type */
         THEN
/* length of my date format */
            l_desctbl (i).col_max_len  := 20;
         ELSIF (l_desctbl (i).col_type = 8)                    /* LONG type */
         THEN
            l_desctbl (i).col_max_len  := 2000;
         END IF;

         l_colcnt_array (i)         := l_desctbl (i).col_name;
      END LOOP;

      l_status                   := DBMS_SQL.EXECUTE (l_thecursor);
      UTL_FILE.put (l_output, '<TRANSACTION_SET><TRANSACTIONS><TRANSACTION>');

      LOOP
         EXIT WHEN (DBMS_SQL.fetch_rows (l_thecursor) <= 0);
         l_line                     := NULL;
         UTL_FILE.put (l_output, '<TROW>');

         FOR i IN 1 .. l_colcnt
         LOOP
            DBMS_SQL.column_value (l_thecursor
,                                  i
,                                  l_columnvalue
                                  );
            UTL_FILE.put (l_output
,                            '<'
                          || l_colcnt_array (i)
                          || '>'
                          || l_columnvalue
                          || '</'
                          || l_colcnt_array (i)
                          || '>');
         END LOOP;

         UTL_FILE.put (l_output, '</TROW>');
         UTL_FILE.new_line (l_output);
         l_cnt                      :=   l_cnt
                                       + 1;
      END LOOP;

      UTL_FILE.put (l_output
,                   '</TRANSACTION></TRANSACTIONS></TRANSACTION_SET>');
      DBMS_SQL.close_cursor (l_thecursor);
      UTL_FILE.fclose (l_output);
      RETURN l_cnt;
   EXCEPTION
      WHEN NO_DATA_FOUND
      THEN
         DBMS_OUTPUT.put_line ('NO_DATA_FOUND');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
      WHEN UTL_FILE.invalid_path
      THEN
         DBMS_OUTPUT.put_line ('UTL_FILE.INVALID_PATH');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
      WHEN UTL_FILE.read_error
      THEN
         DBMS_OUTPUT.put_line ('UTL_FILE.READ_ERROR');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
      WHEN UTL_FILE.write_error
      THEN
         DBMS_OUTPUT.put_line ('UTL_FILE.WRITE_ERROR');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
      WHEN UTL_FILE.invalid_mode
      THEN
         DBMS_OUTPUT.put_line ('UTL_FILE.INVALID_MODE');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
      WHEN UTL_FILE.invalid_filehandle
      THEN
         DBMS_OUTPUT.put_line ('UTL_FILE.INVALID_FILEHANDLE');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
      WHEN UTL_FILE.invalid_operation
      THEN
         DBMS_OUTPUT.put_line ('UTL_FILE.INVALID_OPERATION');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
      WHEN UTL_FILE.internal_error
      THEN
         DBMS_OUTPUT.put_line ('UTL_FILE.INTERNAL_ERROR');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
      WHEN UTL_FILE.invalid_maxlinesize
      THEN
         DBMS_OUTPUT.put_line ('UTL_FILE.INVALID_MAXLINESIZE');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
      WHEN VALUE_ERROR
      THEN
         DBMS_OUTPUT.put_line ('UTL_FILE.VALUE_ERROR');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
      WHEN OTHERS
      THEN
         hum_do.default_exception ('ERROR in dump_csv : ');
         UTL_FILE.fclose (l_output);
         RETURN l_cnt;
   END dump_xml;

   PROCEDURE process_otk_xmldata (
      p_clob                     IN       CLOB
,     p_success                  OUT      VARCHAR2
   )
   IS
      l_message                     VARCHAR2 (32767);
      l_message_array_empty         humcust.hum_toolbox.vcmax_table;
      l_message_array               humcust.hum_toolbox.vcmax_table
                                                     := l_message_array_empty;
      l_success                     VARCHAR2 (2000);
      l_bfile                       BFILE;
      l_clob                        CLOB;
      l_parser                      DBMS_XMLPARSER.parser;
      l_doc                         DBMS_XMLDOM.domdocument;
      l_nl                          DBMS_XMLDOM.domnodelist;
      l_n                           DBMS_XMLDOM.domnode;
      l_temp                        VARCHAR2 (1000);
      l_count                       PLS_INTEGER := 1;
      wellformed                    BOOLEAN;
      errmessage                    VARCHAR2 (32000);

--
--
--
      TYPE r_tab_type IS RECORD (
         employee_number               NUMBER (30)
,        time_entry_date               DATE
,        time_entry_wages              NUMBER (15, 2)
,        vac_time                      NUMBER (15, 2)
,        holiday                       NUMBER (15, 2)
      );

--
      TYPE tab_type IS TABLE OF r_tab_type;

--
--
      t_tab                         tab_type := tab_type ();
   BEGIN
      l_clob                     := p_clob;
      -- Check the syntax of the current 'xmldoc' CLOB in the loop
      checkxmlinclob (c                             => l_clob
,                     wellformed                    => wellformed
,                     error                         => errmessage
                     );

--
      IF NOT wellformed
      THEN
         l_message                  :=
                              'ERROR :: XML Doc is ill-formed :: '
                           || errmessage;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
      ELSE
         -- make sure implicit date conversions are performed correctly
         DBMS_SESSION.set_nls ('NLS_DATE_FORMAT', '''DD-MON-YYYY''');
         -- Create a parser.
         l_parser                   := DBMS_XMLPARSER.newparser;
         -- Parse the document and create a new DOM document.
         DBMS_XMLPARSER.parseclob (l_parser, l_clob);
         l_doc                      := DBMS_XMLPARSER.getdocument (l_parser);
         -- Free resources associated with the Parser now it is no longer needed.
         DBMS_XMLPARSER.freeparser (l_parser);
         -- Get a list of all the EMP nodes in the document using the XPATH syntax.
         l_nl                       :=
            DBMS_XSLPROCESSOR.selectnodes
                            (DBMS_XMLDOM.makenode (l_doc)
,                            '/TRANSACTION_SET/TRANSACTIONS/TRANSACTION/TROW');

--
   -- Loop through the list and create a new record in a tble collection
   -- for each EMP record.
         FOR cur_emp IN 0 ..   DBMS_XMLDOM.getlength (l_nl)
                             - 1
         LOOP
            l_n                        := DBMS_XMLDOM.item (l_nl, cur_emp);
            t_tab.EXTEND;
            -- MAPPING
            -- Use XPATH syntax to assign values to he elements of the collection.
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'EMPNO/text()'
,                                      t_tab (t_tab.LAST).employee_number
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'TIME_ENTRY_DATE/text()'
,                                      t_tab (t_tab.LAST).time_entry_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'TIME_ENTRY_WAGES/text()'
,                                      t_tab (t_tab.LAST).time_entry_wages
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'VAC_TIME/text()'
,                                      t_tab (t_tab.LAST).vac_time
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'HOLIDAY/text()'
,                                      t_tab (t_tab.LAST).holiday
                                      );
         END LOOP;

         -- Insert data into the real EMP table from the table collection.
         -- Form better performance multiple collections should be used to allow
         -- bulk binding using the FORALL construct but this would make the code
         -- too long-winded for this example.
         l_message                  := '<TABLE BORDER="1">';
         l_message                  :=
               l_message
            || '<TR><TD bgcolor="gray">Employee Number</TD><TD bgcolor="gray">Time Entry Date</TD><TD bgcolor="gray">Time Entry Wages</TD><TD bgcolor="gray">Vacation Time</TD><TD bgcolor="gray">Holiday</TD></TR>';

         FOR cur_emp IN t_tab.FIRST .. t_tab.LAST
         LOOP
--
            l_message                  :=    l_message
                                          || '<TR>';
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || t_tab (cur_emp).employee_number
               || '</TD>';
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || t_tab (cur_emp).time_entry_date
               || '</TD>';
            l_message                  :=
                  l_message
               || '<TD align="right">'
               || t_tab (cur_emp).time_entry_wages
               || '</TD>';
            l_message                  :=
                  l_message
               || '<TD align="right">'
               || t_tab (cur_emp).vac_time
               || '</TD>';
            l_message                  :=
                  l_message
               || '<TD align="right">'
               || t_tab (cur_emp).holiday
               || '</TD>';
            l_message                  :=    l_message
                                          || '</TR>';
         END LOOP;

         l_message                  :=    l_message
                                       || '</TABLE>';
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         -- Free any resources associated with the document now it
         -- is no longer needed.
         DBMS_XMLDOM.freedocument (l_doc);
      END IF;

      hum_notifications.send (p_notification_grp_id         => 0
,                             p_to_name                     => 'ztestuser005@humana.com'
,                             p_from_name                   => 'axta_test@humana.com'
,                             p_subject                     => 'TESTING :: Records Processed'
,                             p_priority                    => 3
,                             p_message_array               => l_message_array
,                             p_attachment_name             => NULL
,                             p_directory                   => NULL
,                             p_filename                    => NULL
,                             p_success                     => l_success
                             );
      p_success                  := 'OK';
   EXCEPTION
      WHEN OTHERS
      THEN
         p_success                  :=
                                      'ERROR :: '
                                   || SQLCODE
                                   || ' - '
                                   || SQLERRM;
         l_message                  :=
               'Error on AXTA Transaction '
            || ' :: '
            || SQLCODE
            || ' - '
            || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
   END process_otk_xmldata;

   PROCEDURE process_actotk_email (
      p_clob                     IN       CLOB
,     p_success                  OUT      VARCHAR2
   )
   IS
      l_message                     VARCHAR2 (32767);
      l_message_array_empty         humcust.hum_toolbox.vcmax_table;
      l_message_array               humcust.hum_toolbox.vcmax_table
                                                     := l_message_array_empty;
      l_success                     VARCHAR2 (2000);
      l_bfile                       BFILE;
      l_clob                        CLOB;
      l_parser                      DBMS_XMLPARSER.parser;
      l_doc                         DBMS_XMLDOM.domdocument;
      l_nl                          DBMS_XMLDOM.domnodelist;
      l_n                           DBMS_XMLDOM.domnode;
      l_temp                        VARCHAR2 (1000);
      l_value                       VARCHAR2 (1000);
      l_count                       PLS_INTEGER := 1;
      wellformed                    BOOLEAN;
      errmessage                    VARCHAR2 (32000);

--
--
--
      TYPE r_tab_type IS RECORD (
         employee_number               VARCHAR2 (30 BYTE)
,        time_entry_date               VARCHAR2 (20 BYTE)
,        submission_date               VARCHAR2 (20 BYTE)
,        coid                          NUMBER (5)
,        udn                           NUMBER (3)
,        payroll_id                    NUMBER (2)
,        last_updated_by               VARCHAR2 (30 BYTE)
,        last_update_date              VARCHAR2 (20 BYTE)
,        created_by                    VARCHAR2 (30 BYTE)
,        creation_date                 VARCHAR2 (20 BYTE)
,        time_entry_wages              NUMBER (15, 5)
,        vac_time                      NUMBER (15, 5)
,        personal_day                  NUMBER (15, 5)
,        sick_time                     NUMBER (15, 5)
,        sympathy_pay                  NUMBER (15, 5)
,        jury_duty_pay                 NUMBER (15, 5)
,        unpaid_wc                     NUMBER (15, 5)
,        unpaid_other                  NUMBER (15, 5)
,        shift_hrs                     NUMBER (15, 5)
,        shift_3_hours                 NUMBER (15, 5)
,        weekend_differential          NUMBER (15, 5)
,        on_call_hours                 NUMBER (15, 5)
,        on_call_daily                 NUMBER (3)
,        on_call_holiday               NUMBER (3)
,        on_call_friday                NUMBER (3)
,        on_call_weekend               NUMBER (3)
,        lunch_worked                  NUMBER (15, 5)
,        ca_doubletime                 NUMBER (15, 5)
,        holiday_pay                   NUMBER (15, 5)
,        on_std                        CHAR (1 BYTE)
,        std_qualifying_done           CHAR (1 BYTE)
,        std_qual_no_vac               CHAR (1 BYTE)
,        std_supp_no_stip              CHAR (1 BYTE)
,        std_supp_no_vac               CHAR (1 BYTE)
,        on_fmla                       CHAR (1 BYTE)
,        fmla_int_cont                 CHAR (1 BYTE)
,        fmla_save_vac_week            CHAR (1 BYTE)
,        fmla_no_stip                  CHAR (1 BYTE)
,        fmla_no_vac                   CHAR (1 BYTE)
,        std_qualifying_hours          NUMBER (15, 5)
,        std_fmla_hours                NUMBER (15, 5)
,        fmla_only_hours               NUMBER (15, 5)
,        std_100_hours                 NUMBER (15, 5)
      );

--
      TYPE tab_type IS TABLE OF r_tab_type;

--
--
      t_tab                         tab_type := tab_type ();
      l_step                        VARCHAR2 (100);
   BEGIN
      DBMS_APPLICATION_INFO.set_module ('PROCESS_ACTOTK_EMAIL', NULL);
      l_clob                     := p_clob;
      l_step                     := 'STEP1 :: PROCESS_ACTOTK_EMAIL';
      DBMS_APPLICATION_INFO.set_action (l_step);
      -- Check the syntax of the current 'xmldoc' CLOB in the loop
      checkxmlinclob (c                             => l_clob
,                     wellformed                    => wellformed
,                     error                         => errmessage
                     );
      l_step                     := 'STEP2 :: PROCESS_ACTOTK_EMAIL';
      DBMS_APPLICATION_INFO.set_action (l_step);

--
      IF NOT wellformed
      THEN
         l_message                  :=
                              'ERROR :: XML Doc is ill-formed :: '
                           || errmessage;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         l_step                     := 'STEP3 :: PROCESS_ACTOTK_EMAIL';
         DBMS_APPLICATION_INFO.set_action (l_step);
      ELSE
         l_step                     := 'STEP4 :: PROCESS_ACTOTK_EMAIL';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- make sure implicit date conversions are performed correctly
         DBMS_SESSION.set_nls ('NLS_DATE_FORMAT', '''DD-MON-YYYY''');
         l_step                     := 'STEP4 :: PROCESS_ACTOTK_EMAIL';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Create a parser.
         l_parser                   := DBMS_XMLPARSER.newparser;
         l_step                     := 'STEP5 :: PROCESS_ACTOTK_EMAIL';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Parse the document and create a new DOM document.
         DBMS_XMLPARSER.parseclob (l_parser, l_clob);
         l_doc                      := DBMS_XMLPARSER.getdocument (l_parser);
         l_step                     := 'STEP6 :: PROCESS_ACTOTK_EMAIL';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Free resources associated with the Parser now it is no longer needed.
         DBMS_XMLPARSER.freeparser (l_parser);
         l_step                     := 'STEP7 :: PROCESS_ACTOTK_EMAIL';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Get a list of all the EMP nodes in the document using the XPATH syntax.
         l_nl                       :=
            DBMS_XSLPROCESSOR.selectnodes
                            (DBMS_XMLDOM.makenode (l_doc)
,                            '/TRANSACTION_SET/TRANSACTIONS/TRANSACTION/TROW');
         l_step                     := 'STEP8 :: PROCESS_ACTOTK_EMAIL';
         DBMS_APPLICATION_INFO.set_action (l_step);

         -- Loop through the list and create a new record in a tble collection
         -- for each EMP record.
         FOR cur_emp IN 0 ..   DBMS_XMLDOM.getlength (l_nl)
                             - 1
         LOOP
            l_n                        := DBMS_XMLDOM.item (l_nl, cur_emp);
            t_tab.EXTEND;
            -- MAPPING
            -- Use XPATH syntax to assign values to he elements of the collection.
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'EMPLOYEE_NUMBER/text()'
,                                      t_tab (t_tab.LAST).employee_number
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'TIME_ENTRY_DATE/text()'
,                                      t_tab (t_tab.LAST).time_entry_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SUBMISSION_DATE/text()'
,                                      t_tab (t_tab.LAST).submission_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'COID/text()'
,                                      t_tab (t_tab.LAST).coid
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'UDN/text()'
,                                      t_tab (t_tab.LAST).udn
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'PAYROLL_ID/text()'
,                                      t_tab (t_tab.LAST).payroll_id
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'LAST_UPDATED_BY/text()'
,                                      t_tab (t_tab.LAST).last_updated_by
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'LAST_UPDATE_DATE/text()'
,                                      t_tab (t_tab.LAST).last_update_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'CREATED_BY/text()'
,                                      t_tab (t_tab.LAST).created_by
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'CREATION_DATE/text()'
,                                      t_tab (t_tab.LAST).creation_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'TIME_ENTRY_WAGES/text()'
,                                      t_tab (t_tab.LAST).time_entry_wages
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'VAC_TIME/text()'
,                                      t_tab (t_tab.LAST).vac_time
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'PERSONAL_DAY/text()'
,                                      t_tab (t_tab.LAST).personal_day
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SICK_TIME/text()'
,                                      t_tab (t_tab.LAST).sick_time
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SYMPATHY_PAY/text()'
,                                      t_tab (t_tab.LAST).sympathy_pay
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'JURY_DUTY_PAY/text()'
,                                      t_tab (t_tab.LAST).jury_duty_pay
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'UNPAID_WC/text()'
,                                      t_tab (t_tab.LAST).unpaid_wc
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'UNPAID_OTHER/text()'
,                                      t_tab (t_tab.LAST).unpaid_other
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SHIFT_HRS/text()'
,                                      t_tab (t_tab.LAST).shift_hrs
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SHIFT_3_HOURS/text()'
,                                      t_tab (t_tab.LAST).shift_3_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'WEEKEND_DIFFERENTIAL/text()'
,                                      t_tab (t_tab.LAST).weekend_differential
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_HOURS/text()'
,                                      t_tab (t_tab.LAST).on_call_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_DAILY/text()'
,                                      t_tab (t_tab.LAST).on_call_daily
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_HOLIDAY/text()'
,                                      t_tab (t_tab.LAST).on_call_holiday
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_FRIDAY/text()'
,                                      t_tab (t_tab.LAST).on_call_friday
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_WEEKEND/text()'
,                                      t_tab (t_tab.LAST).on_call_weekend
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'LUNCH_WORKED/text()'
,                                      t_tab (t_tab.LAST).lunch_worked
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'CA_DOUBLETIME/text()'
,                                      t_tab (t_tab.LAST).ca_doubletime
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'HOLIDAY_PAY/text()'
,                                      t_tab (t_tab.LAST).holiday_pay
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_STD/text()'
,                                      t_tab (t_tab.LAST).on_std
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_QUALIFYING_DONE/text()'
,                                      t_tab (t_tab.LAST).std_qualifying_done
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_QUAL_NO_VAC/text()'
,                                      t_tab (t_tab.LAST).std_qual_no_vac
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_SUPP_NO_STIP/text()'
,                                      t_tab (t_tab.LAST).std_supp_no_stip
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_SUPP_NO_VAC/text()'
,                                      t_tab (t_tab.LAST).std_supp_no_vac
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_FMLA/text()'
,                                      t_tab (t_tab.LAST).on_fmla
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_INT_CONT/text()'
,                                      t_tab (t_tab.LAST).fmla_int_cont
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_SAVE_VAC_WEEK/text()'
,                                      t_tab (t_tab.LAST).fmla_save_vac_week
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_NO_STIP/text()'
,                                      t_tab (t_tab.LAST).fmla_no_stip
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_NO_VAC/text()'
,                                      t_tab (t_tab.LAST).fmla_no_vac
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_QUALIFYING_HOURS/text()'
,                                      t_tab (t_tab.LAST).std_qualifying_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_FMLA_HOURS/text()'
,                                      t_tab (t_tab.LAST).std_fmla_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_ONLY_HOURS/text()'
,                                      t_tab (t_tab.LAST).fmla_only_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_100_HOURS/text()'
,                                      t_tab (t_tab.LAST).std_100_hours
                                      );
         END LOOP;

         l_step                     := 'STEP9 :: PROCESS_ACTOTK_EMAIL';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Insert data into the real EMP table from the table collection.
         -- Form better performance multiple collections should be used to allow
         -- bulk binding using the FORALL construct but this would make the code
         -- too long-winded for this example.
         l_message                  := '<TABLE BORDER="1">';
         l_message                  :=
               l_message
            || '<TR>'
            || '<TD bgcolor="gray">EMPLOYEE_NUMBER</TD>'
            || '<TD bgcolor="gray">TIME_ENTRY_DATE</TD>'
            || '<TD bgcolor="gray">SUBMISSION_DATE</TD>'
            || '<TD bgcolor="gray">COID</TD>'
            || '<TD bgcolor="gray">UDN</TD>'
            || '<TD bgcolor="gray">PAYROLL_ID</TD>'
            || '<TD bgcolor="gray">LAST_UPDATED_BY</TD>'
            || '<TD bgcolor="gray">LAST_UPDATE_DATE</TD>'
            || '<TD bgcolor="gray">CREATED_BY</TD>'
            || '<TD bgcolor="gray">CREATION_DATE</TD>'
            || '<TD bgcolor="gray">TIME_ENTRY_WAGES</TD>'
            || '<TD bgcolor="gray">VAC_TIME</TD>'
            || '<TD bgcolor="gray">PERSONAL_DAY</TD>'
            || '<TD bgcolor="gray">SICK_TIME</TD>'
            || '<TD bgcolor="gray">SYMPATHY_PAY</TD>'
            || '<TD bgcolor="gray">JURY_DUTY_PAY</TD>'
            || '<TD bgcolor="gray">UNPAID_WC</TD>'
            || '<TD bgcolor="gray">UNPAID_OTHER</TD>'
            || '<TD bgcolor="gray">SHIFT_HRS</TD>'
            || '<TD bgcolor="gray">SHIFT_3_HOURS</TD>'
            || '<TD bgcolor="gray">WEEKEND_DIFFERENTIAL</TD>'
            || '<TD bgcolor="gray">ON_CALL_HOURS</TD>'
            || '<TD bgcolor="gray">ON_CALL_DAILY</TD>'
            || '<TD bgcolor="gray">ON_CALL_HOLIDAY</TD>'
            || '<TD bgcolor="gray">ON_CALL_FRIDAY</TD>'
            || '<TD bgcolor="gray">ON_CALL_WEEKEND</TD>'
            || '<TD bgcolor="gray">LUNCH_WORKED</TD>'
            || '<TD bgcolor="gray">CA_DOUBLETIME</TD>'
            || '<TD bgcolor="gray">HOLIDAY_PAY</TD>'
            || '<TD bgcolor="gray">ON_STD</TD>'
            || '<TD bgcolor="gray">STD_QUALIFYING_DONE</TD>'
            || '<TD bgcolor="gray">STD_QUAL_NO_VAC</TD>'
            || '<TD bgcolor="gray">STD_SUPP_NO_STIP</TD>'
            || '<TD bgcolor="gray">STD_SUPP_NO_VAC</TD>'
            || '<TD bgcolor="gray">ON_FMLA</TD>'
            || '<TD bgcolor="gray">FMLA_INT_CONT</TD>'
            || '<TD bgcolor="gray">FMLA_SAVE_VAC_WEEK</TD>'
            || '<TD bgcolor="gray">FMLA_NO_STIP</TD>'
            || '<TD bgcolor="gray">FMLA_NO_VAC</TD>'
            || '<TD bgcolor="gray">STD_QUALIFYING_HOURS</TD>'
            || '<TD bgcolor="gray">STD_FMLA_HOURS</TD>'
            || '<TD bgcolor="gray">FMLA_ONLY_HOURS</TD>'
            || '<TD bgcolor="gray">STD_100_HOURS</TD>'
            || '</TR>';
         l_step                     := 'STEP10 :: PROCESS_ACTOTK_EMAIL';
         DBMS_APPLICATION_INFO.set_action (l_step);

         FOR cur_emp IN t_tab.FIRST .. t_tab.LAST
         LOOP
--
            l_message                  :=    l_message
                                          || '<TR>';
            l_value                    := t_tab (cur_emp).employee_number;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).time_entry_date;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).submission_date;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).coid;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).udn;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).payroll_id;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).last_updated_by;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).last_update_date;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).created_by;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).creation_date;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).time_entry_wages;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).vac_time;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).personal_day;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).sick_time;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).sympathy_pay;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).jury_duty_pay;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).unpaid_wc;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).unpaid_other;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).shift_hrs;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).shift_3_hours;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).weekend_differential;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).on_call_hours;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).on_call_daily;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).on_call_holiday;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).on_call_friday;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).on_call_weekend;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).lunch_worked;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).ca_doubletime;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).holiday_pay;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).on_std;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).std_qualifying_done;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).std_qual_no_vac;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).std_supp_no_stip;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).std_supp_no_vac;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).on_fmla;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).fmla_int_cont;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).fmla_save_vac_week;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).fmla_no_stip;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).fmla_no_vac;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).std_qualifying_hours;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).std_fmla_hours;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).fmla_only_hours;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_value                    := t_tab (cur_emp).std_100_hours;
            l_message                  :=
                  l_message
               || '<TD align="left">'
               || NVL (l_value, ' ')
               || '</TD>';
            l_message                  :=    l_message
                                          || '</TR>';
            l_count                    :=   l_count
                                          + 1;
            EXIT WHEN l_count = 10;
         END LOOP;

         l_step                     := 'STEP11 :: PROCESS_ACTOTK_EMAIL';
         DBMS_APPLICATION_INFO.set_action (l_step);
         l_message                  :=    l_message
                                       || '</TABLE>';
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         -- Free any resources associated with the document now it
         -- is no longer needed.
         DBMS_XMLDOM.freedocument (l_doc);
      END IF;

      l_step                     := 'STEP12 :: PROCESS_ACTOTK_EMAIL';
      DBMS_APPLICATION_INFO.set_action (l_step);
      hum_notifications.send
                           (p_notification_grp_id         => 0
,                           p_to_name                     => 'ztestuser005@humana.com'
,                           p_from_name                   => 'axta_test@humana.com'
,                           p_subject                     => 'TESTING :: Records Processed Email'
,                           p_priority                    => 3
,                           p_message_array               => l_message_array
,                           p_attachment_name             => NULL
,                           p_directory                   => NULL
,                           p_filename                    => NULL
,                           p_success                     => l_success
                           );
      p_success                  := 'OK';
      l_step                     := 'STEP99 :: PROCESS_ACTOTK_EMAIL';
   EXCEPTION
      WHEN OTHERS
      THEN
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
   END process_actotk_email;

   PROCEDURE process_actotk_file (
      p_clob                     IN       CLOB
,     p_success                  OUT      VARCHAR2
   )
   IS
      l_message                     VARCHAR2 (32767);
      l_message_array_empty         humcust.hum_toolbox.vcmax_table;
      l_message_array               humcust.hum_toolbox.vcmax_table
                                                     := l_message_array_empty;
      l_success                     VARCHAR2 (2000);
      l_bfile                       BFILE;
      l_clob                        CLOB;
      l_parser                      DBMS_XMLPARSER.parser;
      l_doc                         DBMS_XMLDOM.domdocument;
      l_nl                          DBMS_XMLDOM.domnodelist;
      l_n                           DBMS_XMLDOM.domnode;
      l_temp                        VARCHAR2 (1000);
      l_value                       VARCHAR2 (1000);
      l_count                       PLS_INTEGER := 1;
      wellformed                    BOOLEAN := TRUE;
      errmessage                    VARCHAR2 (32000);
      l_output                      UTL_FILE.file_type;

--
--
--
      TYPE r_tab_type IS RECORD (
         employee_number               VARCHAR2 (30 BYTE)
,        time_entry_date               VARCHAR2 (20 BYTE)
,        submission_date               VARCHAR2 (20 BYTE)
,        coid                          NUMBER (5)
,        udn                           NUMBER (3)
,        payroll_id                    NUMBER (2)
,        last_updated_by               VARCHAR2 (30 BYTE)
,        last_update_date              VARCHAR2 (20 BYTE)
,        created_by                    VARCHAR2 (30 BYTE)
,        creation_date                 VARCHAR2 (20 BYTE)
,        time_entry_wages              NUMBER (15, 5)
,        vac_time                      NUMBER (15, 5)
,        personal_day                  NUMBER (15, 5)
,        sick_time                     NUMBER (15, 5)
,        sympathy_pay                  NUMBER (15, 5)
,        jury_duty_pay                 NUMBER (15, 5)
,        unpaid_wc                     NUMBER (15, 5)
,        unpaid_other                  NUMBER (15, 5)
,        shift_hrs                     NUMBER (15, 5)
,        shift_3_hours                 NUMBER (15, 5)
,        weekend_differential          NUMBER (15, 5)
,        on_call_hours                 NUMBER (15, 5)
,        on_call_daily                 NUMBER (3)
,        on_call_holiday               NUMBER (3)
,        on_call_friday                NUMBER (3)
,        on_call_weekend               NUMBER (3)
,        lunch_worked                  NUMBER (15, 5)
,        ca_doubletime                 NUMBER (15, 5)
,        holiday_pay                   NUMBER (15, 5)
,        on_std                        CHAR (1 BYTE)
,        std_qualifying_done           CHAR (1 BYTE)
,        std_qual_no_vac               CHAR (1 BYTE)
,        std_supp_no_stip              CHAR (1 BYTE)
,        std_supp_no_vac               CHAR (1 BYTE)
,        on_fmla                       CHAR (1 BYTE)
,        fmla_int_cont                 CHAR (1 BYTE)
,        fmla_save_vac_week            CHAR (1 BYTE)
,        fmla_no_stip                  CHAR (1 BYTE)
,        fmla_no_vac                   CHAR (1 BYTE)
,        std_qualifying_hours          NUMBER (15, 5)
,        std_fmla_hours                NUMBER (15, 5)
,        fmla_only_hours               NUMBER (15, 5)
,        std_100_hours                 NUMBER (15, 5)
      );

--
      TYPE tab_type IS TABLE OF r_tab_type;

--
--
      t_tab                         tab_type := tab_type ();
      l_step                        VARCHAR2 (100);
   BEGIN
      DBMS_APPLICATION_INFO.set_module ('PROCESS_ACTOTK_FILE', NULL);
      l_step                     := 'STEP1 :: PROCESS_ACTOTK_FILE';
      DBMS_APPLICATION_INFO.set_action (l_step);
      l_clob                     := p_clob;
-- Check the syntax of the current 'xmldoc' CLOB in the loop
      checkxmlinclob (c                             => l_clob
,                     wellformed                    => wellformed
,                     error                         => errmessage
                     );
      l_step                     := 'STEP2 :: PROCESS_ACTOTK_FILE';
      DBMS_APPLICATION_INFO.set_action (l_step);

--
      IF NOT wellformed
      THEN
         l_step                     := 'STEP3 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         l_message                  :=
                              'ERROR :: XML Doc is ill-formed :: '
                           || errmessage;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
      ELSE
         l_step                     := 'STEP4 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- make sure implicit date conversions are performed correctly
         DBMS_SESSION.set_nls ('NLS_DATE_FORMAT', '''DD-MON-YYYY''');
         -- Create a parser.
         l_parser                   := DBMS_XMLPARSER.newparser;
         l_step                     := 'STEP5 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Parse the document and create a new DOM document.
         DBMS_XMLPARSER.parseclob (l_parser, l_clob);
         l_step                     := 'STEP6 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         l_doc                      := DBMS_XMLPARSER.getdocument (l_parser);
         l_step                     := 'STEP7 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Free resources associated with the Parser now it is no longer needed.
         DBMS_XMLPARSER.freeparser (l_parser);
         l_step                     := 'STEP8 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Get a list of all the EMP nodes in the document using the XPATH syntax.
         l_nl                       :=
            DBMS_XSLPROCESSOR.selectnodes
                            (DBMS_XMLDOM.makenode (l_doc)
,                            '/TRANSACTION_SET/TRANSACTIONS/TRANSACTION/TROW');
         l_step                     := 'STEP9 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);

--
   -- Loop through the list and create a new record in a tble collection
   -- for each EMP record.
         FOR cur_emp IN 0 ..   DBMS_XMLDOM.getlength (l_nl)
                             - 1
         LOOP
            l_n                        := DBMS_XMLDOM.item (l_nl, cur_emp);
            t_tab.EXTEND;
            -- MAPPING
            -- Use XPATH syntax to assign values to he elements of the collection.
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'EMPLOYEE_NUMBER/text()'
,                                      t_tab (t_tab.LAST).employee_number
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'TIME_ENTRY_DATE/text()'
,                                      t_tab (t_tab.LAST).time_entry_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SUBMISSION_DATE/text()'
,                                      t_tab (t_tab.LAST).submission_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'COID/text()'
,                                      t_tab (t_tab.LAST).coid
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'UDN/text()'
,                                      t_tab (t_tab.LAST).udn
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'PAYROLL_ID/text()'
,                                      t_tab (t_tab.LAST).payroll_id
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'LAST_UPDATED_BY/text()'
,                                      t_tab (t_tab.LAST).last_updated_by
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'LAST_UPDATE_DATE/text()'
,                                      t_tab (t_tab.LAST).last_update_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'CREATED_BY/text()'
,                                      t_tab (t_tab.LAST).created_by
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'CREATION_DATE/text()'
,                                      t_tab (t_tab.LAST).creation_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'TIME_ENTRY_WAGES/text()'
,                                      t_tab (t_tab.LAST).time_entry_wages
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'VAC_TIME/text()'
,                                      t_tab (t_tab.LAST).vac_time
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'PERSONAL_DAY/text()'
,                                      t_tab (t_tab.LAST).personal_day
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SICK_TIME/text()'
,                                      t_tab (t_tab.LAST).sick_time
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SYMPATHY_PAY/text()'
,                                      t_tab (t_tab.LAST).sympathy_pay
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'JURY_DUTY_PAY/text()'
,                                      t_tab (t_tab.LAST).jury_duty_pay
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'UNPAID_WC/text()'
,                                      t_tab (t_tab.LAST).unpaid_wc
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'UNPAID_OTHER/text()'
,                                      t_tab (t_tab.LAST).unpaid_other
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SHIFT_HRS/text()'
,                                      t_tab (t_tab.LAST).shift_hrs
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SHIFT_3_HOURS/text()'
,                                      t_tab (t_tab.LAST).shift_3_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'WEEKEND_DIFFERENTIAL/text()'
,                                      t_tab (t_tab.LAST).weekend_differential
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_HOURS/text()'
,                                      t_tab (t_tab.LAST).on_call_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_DAILY/text()'
,                                      t_tab (t_tab.LAST).on_call_daily
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_HOLIDAY/text()'
,                                      t_tab (t_tab.LAST).on_call_holiday
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_FRIDAY/text()'
,                                      t_tab (t_tab.LAST).on_call_friday
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_WEEKEND/text()'
,                                      t_tab (t_tab.LAST).on_call_weekend
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'LUNCH_WORKED/text()'
,                                      t_tab (t_tab.LAST).lunch_worked
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'CA_DOUBLETIME/text()'
,                                      t_tab (t_tab.LAST).ca_doubletime
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'HOLIDAY_PAY/text()'
,                                      t_tab (t_tab.LAST).holiday_pay
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_STD/text()'
,                                      t_tab (t_tab.LAST).on_std
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_QUALIFYING_DONE/text()'
,                                      t_tab (t_tab.LAST).std_qualifying_done
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_QUAL_NO_VAC/text()'
,                                      t_tab (t_tab.LAST).std_qual_no_vac
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_SUPP_NO_STIP/text()'
,                                      t_tab (t_tab.LAST).std_supp_no_stip
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_SUPP_NO_VAC/text()'
,                                      t_tab (t_tab.LAST).std_supp_no_vac
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_FMLA/text()'
,                                      t_tab (t_tab.LAST).on_fmla
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_INT_CONT/text()'
,                                      t_tab (t_tab.LAST).fmla_int_cont
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_SAVE_VAC_WEEK/text()'
,                                      t_tab (t_tab.LAST).fmla_save_vac_week
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_NO_STIP/text()'
,                                      t_tab (t_tab.LAST).fmla_no_stip
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_NO_VAC/text()'
,                                      t_tab (t_tab.LAST).fmla_no_vac
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_QUALIFYING_HOURS/text()'
,                                      t_tab (t_tab.LAST).std_qualifying_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_FMLA_HOURS/text()'
,                                      t_tab (t_tab.LAST).std_fmla_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_ONLY_HOURS/text()'
,                                      t_tab (t_tab.LAST).fmla_only_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_100_HOURS/text()'
,                                      t_tab (t_tab.LAST).std_100_hours
                                      );
         END LOOP;

         l_step                     := 'STEP10 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Insert data into the real EMP table from the table collection.
         -- Form better performance multiple collections should be used to allow
         -- bulk binding using the FORALL construct but this would make the code
         -- too long-winded for this example.
         l_output                   :=
             UTL_FILE.fopen ('INTF0047_TABLES'
,                            'hum_at_feed.csv'
,                            'w'
,                            32000
                            );

         FOR cur_emp IN t_tab.FIRST .. t_tab.LAST
         LOOP
            l_message                  := NULL;
--
            l_value                    := t_tab (cur_emp).employee_number;
            l_message                  :=
                                       l_message
                                    || '"'
                                    || l_value
                                    || '"'
                                    || ',';
            l_value                    := t_tab (cur_emp).time_entry_date;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).submission_date;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).coid;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).udn;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).payroll_id;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).last_updated_by;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).last_update_date;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).created_by;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).creation_date;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).time_entry_wages;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).vac_time;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).personal_day;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).sick_time;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).sympathy_pay;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).jury_duty_pay;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).unpaid_wc;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).unpaid_other;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).shift_hrs;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).shift_3_hours;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).weekend_differential;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).on_call_hours;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).on_call_daily;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).on_call_holiday;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).on_call_friday;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).on_call_weekend;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).lunch_worked;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).ca_doubletime;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).holiday_pay;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).on_std;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).std_qualifying_done;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).std_qual_no_vac;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).std_supp_no_stip;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).std_supp_no_vac;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).on_fmla;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).fmla_int_cont;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).fmla_save_vac_week;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).fmla_no_stip;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).fmla_no_vac;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).std_qualifying_hours;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).std_fmla_hours;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).fmla_only_hours;
            l_message                  :=
                                        l_message
                                     || '"'
                                     || l_value
                                     || '"'
                                     || ',';
            l_value                    := t_tab (cur_emp).std_100_hours;
            l_message                  :=    l_message
                                          || '"'
                                          || l_value
                                          || '"';
            UTL_FILE.put (l_output, l_message);
            UTL_FILE.new_line (l_output);
            l_count                    :=   l_count
                                          + 1;
            EXIT WHEN l_count = 10;
         END LOOP;

         l_step                     := 'STEP11 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         UTL_FILE.fclose (l_output);
         l_message                  :=
            'File Generated. Run SELECT * FROM TIMEMAINT.HUM_AT_FEED to test and view data.';
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         l_step                     := 'STEP12 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Free any resources associated with the document now it
         -- is no longer needed.
         DBMS_XMLDOM.freedocument (l_doc);
         l_step                     := 'STEP99 :: PROCESS_ACTOTK_FILE';
         DBMS_APPLICATION_INFO.set_action (l_step);
      END IF;

      hum_notifications.send
                           (p_notification_grp_id         => 0
,                           p_to_name                     => 'ztestuser005@humana.com'
,                           p_from_name                   => 'axta_test@humana.com'
,                           p_subject                     => 'TESTING :: Records Processed Email'
,                           p_priority                    => 3
,                           p_message_array               => l_message_array
,                           p_attachment_name             => NULL
,                           p_directory                   => NULL
,                           p_filename                    => NULL
,                           p_success                     => l_success
                           );
      p_success                  := 'OK';
   EXCEPTION
      WHEN NO_DATA_FOUND
      THEN
         UTL_FILE.fclose (l_output);
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
      WHEN UTL_FILE.invalid_path
      THEN
         UTL_FILE.fclose (l_output);
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
      WHEN UTL_FILE.read_error
      THEN
         UTL_FILE.fclose (l_output);
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
      WHEN UTL_FILE.write_error
      THEN
         UTL_FILE.fclose (l_output);
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
      WHEN UTL_FILE.invalid_mode
      THEN
         UTL_FILE.fclose (l_output);
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
      WHEN UTL_FILE.invalid_filehandle
      THEN
         UTL_FILE.fclose (l_output);
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
      WHEN UTL_FILE.invalid_operation
      THEN
         UTL_FILE.fclose (l_output);
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
      WHEN UTL_FILE.internal_error
      THEN
         UTL_FILE.fclose (l_output);
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
      WHEN UTL_FILE.invalid_maxlinesize
      THEN
         UTL_FILE.fclose (l_output);
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
      WHEN VALUE_ERROR
      THEN
         UTL_FILE.fclose (l_output);
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
      WHEN OTHERS
      THEN
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
   END process_actotk_file;

   PROCEDURE process_actotk_table (
      p_clob                     IN       CLOB
,     p_success                  OUT      VARCHAR2
   )
   IS
      l_message                     VARCHAR2 (32767);
      l_message_array_empty         humcust.hum_toolbox.vcmax_table;
      l_message_array               humcust.hum_toolbox.vcmax_table
                                                     := l_message_array_empty;
      l_success                     VARCHAR2 (2000);
      l_bfile                       BFILE;
      l_clob                        CLOB;
      l_parser                      DBMS_XMLPARSER.parser;
      l_doc                         DBMS_XMLDOM.domdocument;
      l_nl                          DBMS_XMLDOM.domnodelist;
      l_n                           DBMS_XMLDOM.domnode;
      l_temp                        VARCHAR2 (1000);
      l_value                       VARCHAR2 (1000);
      l_count                       PLS_INTEGER := 1;
      wellformed                    BOOLEAN;
      errmessage                    VARCHAR2 (32000);
      lbok                          BOOLEAN;

--
--
-- create table temp_hum_at_feed
-- (
--          employee_number               VARCHAR2 (30 BYTE)
-- ,        time_entry_date               VARCHAR2 (20 BYTE)
-- ,        submission_date               VARCHAR2 (20 BYTE)
-- ,        coid                          NUMBER (5)
-- ,        udn                           NUMBER (3)
-- ,        payroll_id                    NUMBER (2)
-- ,        last_updated_by               VARCHAR2 (30 BYTE)
-- ,        last_update_date              VARCHAR2 (20 BYTE)
-- ,        created_by                    VARCHAR2 (30 BYTE)
-- ,        creation_date                 VARCHAR2 (20 BYTE)
-- ,        time_entry_wages              NUMBER (15, 5)
-- ,        vac_time                      NUMBER (15, 5)
-- ,        personal_day                  NUMBER (15, 5)
-- ,        sick_time                     NUMBER (15, 5)
-- ,        sympathy_pay                  NUMBER (15, 5)
-- ,        jury_duty_pay                 NUMBER (15, 5)
-- ,        unpaid_wc                     NUMBER (15, 5)
-- ,        unpaid_other                  NUMBER (15, 5)
-- ,        shift_hrs                     NUMBER (15, 5)
-- ,        shift_3_hours                 NUMBER (15, 5)
-- ,        weekend_differential          NUMBER (15, 5)
-- ,        on_call_hours                 NUMBER (15, 5)
-- ,        on_call_daily                 NUMBER (3)
-- ,        on_call_holiday               NUMBER (3)
-- ,        on_call_friday                NUMBER (3)
-- ,        on_call_weekend               NUMBER (3)
-- ,        lunch_worked                  NUMBER (15, 5)
-- ,        ca_doubletime                 NUMBER (15, 5)
-- ,        holiday_pay                   NUMBER (15, 5)
-- ,        on_std                        CHAR (1 BYTE)
-- ,        std_qualifying_done           CHAR (1 BYTE)
-- ,        std_qual_no_vac               CHAR (1 BYTE)
-- ,        std_supp_no_stip              CHAR (1 BYTE)
-- ,        std_supp_no_vac               CHAR (1 BYTE)
-- ,        on_fmla                       CHAR (1 BYTE)
-- ,        fmla_int_cont                 CHAR (1 BYTE)
-- ,        fmla_save_vac_week            CHAR (1 BYTE)
-- ,        fmla_no_stip                  CHAR (1 BYTE)
-- ,        fmla_no_vac                   CHAR (1 BYTE)
-- ,        std_qualifying_hours          NUMBER (15, 5)
-- ,        std_fmla_hours                NUMBER (15, 5)
-- ,        fmla_only_hours               NUMBER (15, 5)
-- ,        std_100_hours                 NUMBER (15, 5)
-- );

      --
      TYPE r_tab_type IS RECORD (
         employee_number               VARCHAR2 (30 BYTE)
,        time_entry_date               VARCHAR2 (20 BYTE)
,        submission_date               VARCHAR2 (20 BYTE)
,        coid                          NUMBER (5)
,        udn                           NUMBER (3)
,        payroll_id                    NUMBER (2)
,        last_updated_by               VARCHAR2 (30 BYTE)
,        last_update_date              VARCHAR2 (20 BYTE)
,        created_by                    VARCHAR2 (30 BYTE)
,        creation_date                 VARCHAR2 (20 BYTE)
,        time_entry_wages              NUMBER (15, 5)
,        vac_time                      NUMBER (15, 5)
,        personal_day                  NUMBER (15, 5)
,        sick_time                     NUMBER (15, 5)
,        sympathy_pay                  NUMBER (15, 5)
,        jury_duty_pay                 NUMBER (15, 5)
,        unpaid_wc                     NUMBER (15, 5)
,        unpaid_other                  NUMBER (15, 5)
,        shift_hrs                     NUMBER (15, 5)
,        shift_3_hours                 NUMBER (15, 5)
,        weekend_differential          NUMBER (15, 5)
,        on_call_hours                 NUMBER (15, 5)
,        on_call_daily                 NUMBER (3)
,        on_call_holiday               NUMBER (3)
,        on_call_friday                NUMBER (3)
,        on_call_weekend               NUMBER (3)
,        lunch_worked                  NUMBER (15, 5)
,        ca_doubletime                 NUMBER (15, 5)
,        holiday_pay                   NUMBER (15, 5)
,        on_std                        CHAR (1 BYTE)
,        std_qualifying_done           CHAR (1 BYTE)
,        std_qual_no_vac               CHAR (1 BYTE)
,        std_supp_no_stip              CHAR (1 BYTE)
,        std_supp_no_vac               CHAR (1 BYTE)
,        on_fmla                       CHAR (1 BYTE)
,        fmla_int_cont                 CHAR (1 BYTE)
,        fmla_save_vac_week            CHAR (1 BYTE)
,        fmla_no_stip                  CHAR (1 BYTE)
,        fmla_no_vac                   CHAR (1 BYTE)
,        std_qualifying_hours          NUMBER (15, 5)
,        std_fmla_hours                NUMBER (15, 5)
,        fmla_only_hours               NUMBER (15, 5)
,        std_100_hours                 NUMBER (15, 5)
      );

--
      TYPE tab_type IS TABLE OF r_tab_type;

--
--
      t_tab                         tab_type := tab_type ();
      l_step                        VARCHAR2 (100);
   BEGIN
      DBMS_APPLICATION_INFO.set_module ('PROCESS_ACTOTK_TABLE', NULL);
      l_clob                     := p_clob;
      l_step                     := 'STEP1 :: PROCESS_ACTOTK_TABLE';
      DBMS_APPLICATION_INFO.set_action (l_step);
      -- Check the syntax of the current 'xmldoc' CLOB in the loop
      checkxmlinclob (c                             => l_clob
,                     wellformed                    => wellformed
,                     error                         => errmessage
                     );
--
      l_step                     := 'STEP2 :: PROCESS_ACTOTK_TABLE';
      DBMS_APPLICATION_INFO.set_action (l_step);

      IF NOT wellformed
      THEN
         l_message                  :=
                              'ERROR :: XML Doc is ill-formed :: '
                           || errmessage;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         l_step                     := 'STEP3 :: PROCESS_ACTOTK_TABLE';
         DBMS_APPLICATION_INFO.set_action (l_step);
      ELSE
         l_step                     := 'STEP4 :: PROCESS_ACTOTK_TABLE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- make sure implicit date conversions are performed correctly
         DBMS_SESSION.set_nls ('NLS_DATE_FORMAT', '''DD-MON-YYYY''');
         l_step                     := 'STEP5 :: PROCESS_ACTOTK_TABLE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Create a parser.
         l_parser                   := DBMS_XMLPARSER.newparser;
         l_step                     := 'STEP6 :: PROCESS_ACTOTK_TABLE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Parse the document and create a new DOM document.
         DBMS_XMLPARSER.parseclob (l_parser, l_clob);
         l_doc                      := DBMS_XMLPARSER.getdocument (l_parser);
         l_step                     := 'STEP7 :: PROCESS_ACTOTK_TABLE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Free resources associated with the Parser now it is no longer needed.
         DBMS_XMLPARSER.freeparser (l_parser);
         l_step                     := 'STEP8 :: PROCESS_ACTOTK_TABLE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Get a list of all the EMP nodes in the document using the XPATH syntax.
         l_nl                       :=
            DBMS_XSLPROCESSOR.selectnodes
                            (DBMS_XMLDOM.makenode (l_doc)
,                            '/TRANSACTION_SET/TRANSACTIONS/TRANSACTION/TROW');
         l_step                     := 'STEP9 :: PROCESS_ACTOTK_TABLE';
         DBMS_APPLICATION_INFO.set_action (l_step);

         -- Loop through the list and create a new record in a tble collection
         -- for each EMP record.
         FOR cur_emp IN 0 ..   DBMS_XMLDOM.getlength (l_nl)
                             - 1
         LOOP
            l_n                        := DBMS_XMLDOM.item (l_nl, cur_emp);
            t_tab.EXTEND;
            -- MAPPING
            -- Use XPATH syntax to assign values to he elements of the collection.
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'EMPLOYEE_NUMBER/text()'
,                                      t_tab (t_tab.LAST).employee_number
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'TIME_ENTRY_DATE/text()'
,                                      t_tab (t_tab.LAST).time_entry_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SUBMISSION_DATE/text()'
,                                      t_tab (t_tab.LAST).submission_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'COID/text()'
,                                      t_tab (t_tab.LAST).coid
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'UDN/text()'
,                                      t_tab (t_tab.LAST).udn
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'PAYROLL_ID/text()'
,                                      t_tab (t_tab.LAST).payroll_id
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'LAST_UPDATED_BY/text()'
,                                      t_tab (t_tab.LAST).last_updated_by
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'LAST_UPDATE_DATE/text()'
,                                      t_tab (t_tab.LAST).last_update_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'CREATED_BY/text()'
,                                      t_tab (t_tab.LAST).created_by
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'CREATION_DATE/text()'
,                                      t_tab (t_tab.LAST).creation_date
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'TIME_ENTRY_WAGES/text()'
,                                      t_tab (t_tab.LAST).time_entry_wages
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'VAC_TIME/text()'
,                                      t_tab (t_tab.LAST).vac_time
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'PERSONAL_DAY/text()'
,                                      t_tab (t_tab.LAST).personal_day
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SICK_TIME/text()'
,                                      t_tab (t_tab.LAST).sick_time
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SYMPATHY_PAY/text()'
,                                      t_tab (t_tab.LAST).sympathy_pay
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'JURY_DUTY_PAY/text()'
,                                      t_tab (t_tab.LAST).jury_duty_pay
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'UNPAID_WC/text()'
,                                      t_tab (t_tab.LAST).unpaid_wc
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'UNPAID_OTHER/text()'
,                                      t_tab (t_tab.LAST).unpaid_other
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SHIFT_HRS/text()'
,                                      t_tab (t_tab.LAST).shift_hrs
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'SHIFT_3_HOURS/text()'
,                                      t_tab (t_tab.LAST).shift_3_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'WEEKEND_DIFFERENTIAL/text()'
,                                      t_tab (t_tab.LAST).weekend_differential
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_HOURS/text()'
,                                      t_tab (t_tab.LAST).on_call_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_DAILY/text()'
,                                      t_tab (t_tab.LAST).on_call_daily
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_HOLIDAY/text()'
,                                      t_tab (t_tab.LAST).on_call_holiday
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_FRIDAY/text()'
,                                      t_tab (t_tab.LAST).on_call_friday
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_CALL_WEEKEND/text()'
,                                      t_tab (t_tab.LAST).on_call_weekend
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'LUNCH_WORKED/text()'
,                                      t_tab (t_tab.LAST).lunch_worked
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'CA_DOUBLETIME/text()'
,                                      t_tab (t_tab.LAST).ca_doubletime
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'HOLIDAY_PAY/text()'
,                                      t_tab (t_tab.LAST).holiday_pay
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_STD/text()'
,                                      t_tab (t_tab.LAST).on_std
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_QUALIFYING_DONE/text()'
,                                      t_tab (t_tab.LAST).std_qualifying_done
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_QUAL_NO_VAC/text()'
,                                      t_tab (t_tab.LAST).std_qual_no_vac
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_SUPP_NO_STIP/text()'
,                                      t_tab (t_tab.LAST).std_supp_no_stip
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_SUPP_NO_VAC/text()'
,                                      t_tab (t_tab.LAST).std_supp_no_vac
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'ON_FMLA/text()'
,                                      t_tab (t_tab.LAST).on_fmla
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_INT_CONT/text()'
,                                      t_tab (t_tab.LAST).fmla_int_cont
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_SAVE_VAC_WEEK/text()'
,                                      t_tab (t_tab.LAST).fmla_save_vac_week
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_NO_STIP/text()'
,                                      t_tab (t_tab.LAST).fmla_no_stip
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_NO_VAC/text()'
,                                      t_tab (t_tab.LAST).fmla_no_vac
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_QUALIFYING_HOURS/text()'
,                                      t_tab (t_tab.LAST).std_qualifying_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_FMLA_HOURS/text()'
,                                      t_tab (t_tab.LAST).std_fmla_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'FMLA_ONLY_HOURS/text()'
,                                      t_tab (t_tab.LAST).fmla_only_hours
                                      );
            DBMS_XSLPROCESSOR.valueof (l_n
,                                      'STD_100_HOURS/text()'
,                                      t_tab (t_tab.LAST).std_100_hours
                                      );
         END LOOP;

         l_step                     := 'STEP10 :: PROCESS_ACTOTK_TABLE';
         DBMS_APPLICATION_INFO.set_action (l_step);
         -- Insert data into the real EMP table from the table collection.
         -- Form better performance multiple collections should be used to allow
         -- bulk binding using the FORALL construct but this would make the code
         -- too long-winded for this example.
         lbok                       :=
            hum_utilities_pk.exec_ddl
                 (pnstatement_txt               => 'TRUNCATE TEMP_HUM_AT_FEED DROP STORAGE'
,                 pverrmsg                      => errmessage);
         l_step                     := 'STEP11 :: PROCESS_ACTOTK_TABLE';
         DBMS_APPLICATION_INFO.set_action (l_step);

         IF errmessage IS NOT NULL
         THEN
            l_message                  :=
                   'ERROR :: TEMP_HUM_AT_FEED TRUNCATE FAILED :: '
                || errmessage;
            l_message_array (1)        := REPLACE (l_message
,                                                  CHR (10)
,                                                  ' '
                                                  );
         ELSE
            FOR cur_emp IN t_tab.FIRST .. t_tab.LAST
            LOOP
               INSERT INTO temp_hum_at_feed
                           (employee_number
,                           time_entry_date
,                           submission_date
,                           coid
,                           udn
,                           payroll_id
,                           last_updated_by
,                           last_update_date
,                           created_by
,                           creation_date
,                           time_entry_wages
,                           vac_time
,                           personal_day
,                           sick_time
,                           sympathy_pay
,                           jury_duty_pay
,                           unpaid_wc
,                           unpaid_other
,                           shift_hrs
,                           shift_3_hours
,                           weekend_differential
,                           on_call_hours
,                           on_call_daily
,                           on_call_holiday
,                           on_call_friday
,                           on_call_weekend
,                           lunch_worked
,                           ca_doubletime
,                           holiday_pay
,                           on_std
,                           std_qualifying_done
,                           std_qual_no_vac
,                           std_supp_no_stip
,                           std_supp_no_vac
,                           on_fmla
,                           fmla_int_cont
,                           fmla_save_vac_week
,                           fmla_no_stip
,                           fmla_no_vac
,                           std_qualifying_hours
,                           std_fmla_hours
,                           fmla_only_hours
,                           std_100_hours
                           )
                    VALUES (t_tab (cur_emp).employee_number
,                           t_tab (cur_emp).time_entry_date
,                           t_tab (cur_emp).submission_date
,                           t_tab (cur_emp).coid
,                           t_tab (cur_emp).udn
,                           t_tab (cur_emp).payroll_id
,                           t_tab (cur_emp).last_updated_by
,                           t_tab (cur_emp).last_update_date
,                           t_tab (cur_emp).created_by
,                           t_tab (cur_emp).creation_date
,                           t_tab (cur_emp).time_entry_wages
,                           t_tab (cur_emp).vac_time
,                           t_tab (cur_emp).personal_day
,                           t_tab (cur_emp).sick_time
,                           t_tab (cur_emp).sympathy_pay
,                           t_tab (cur_emp).jury_duty_pay
,                           t_tab (cur_emp).unpaid_wc
,                           t_tab (cur_emp).unpaid_other
,                           t_tab (cur_emp).shift_hrs
,                           t_tab (cur_emp).shift_3_hours
,                           t_tab (cur_emp).weekend_differential
,                           t_tab (cur_emp).on_call_hours
,                           t_tab (cur_emp).on_call_daily
,                           t_tab (cur_emp).on_call_holiday
,                           t_tab (cur_emp).on_call_friday
,                           t_tab (cur_emp).on_call_weekend
,                           t_tab (cur_emp).lunch_worked
,                           t_tab (cur_emp).ca_doubletime
,                           t_tab (cur_emp).holiday_pay
,                           t_tab (cur_emp).on_std
,                           t_tab (cur_emp).std_qualifying_done
,                           t_tab (cur_emp).std_qual_no_vac
,                           t_tab (cur_emp).std_supp_no_stip
,                           t_tab (cur_emp).std_supp_no_vac
,                           t_tab (cur_emp).on_fmla
,                           t_tab (cur_emp).fmla_int_cont
,                           t_tab (cur_emp).fmla_save_vac_week
,                           t_tab (cur_emp).fmla_no_stip
,                           t_tab (cur_emp).fmla_no_vac
,                           t_tab (cur_emp).std_qualifying_hours
,                           t_tab (cur_emp).std_fmla_hours
,                           t_tab (cur_emp).fmla_only_hours
,                           t_tab (cur_emp).std_100_hours
                           );

               COMMIT;
               l_count                    :=   l_count
                                             + 1;
               EXIT WHEN l_count = 10;
            END LOOP;

            l_message                  :=
               'File Generated. Run SELECT * FROM APPS.TEMP_HUM_AT_FEED to test and view data.';
            l_message_array (1)        := REPLACE (l_message
,                                                  CHR (10)
,                                                  ' '
                                                  );
         END IF;

         -- Free any resources associated with the document now it
         -- is no longer needed.
         DBMS_XMLDOM.freedocument (l_doc);
      END IF;

      l_step                     := 'STEP12 :: PROCESS_ACTOTK_TABLE';
      DBMS_APPLICATION_INFO.set_action (l_step);
      hum_notifications.send
                           (p_notification_grp_id         => 0
,                           p_to_name                     => 'ztestuser005@humana.com'
,                           p_from_name                   => 'axta_test@humana.com'
,                           p_subject                     => 'TESTING :: Records Processed Email'
,                           p_priority                    => 3
,                           p_message_array               => l_message_array
,                           p_attachment_name             => NULL
,                           p_directory                   => NULL
,                           p_filename                    => NULL
,                           p_success                     => l_success
                           );
      p_success                  := 'OK';
      l_step                     := 'STEP99 :: PROCESS_ACTOTK_TABLE';
   EXCEPTION
      WHEN OTHERS
      THEN
         p_success                  :=
                                      'ERROR :: '
                                   || l_step
                                   || ' :: '
                                   || SQLERRM;
         l_message                  :=
                                       'ERROR :: '
                                    || l_step
                                    || ' :: '
                                    || SQLERRM;
         l_message_array (1)        := REPLACE (l_message
,                                               CHR (10)
,                                               ' '
                                               );
         hum_notifications.send
            (p_notification_grp_id         => 0
,            p_to_name                     => 'ztestuser005@humana.com'
,            p_from_name                   => 'axta_test@humana.com'
,            p_subject                     =>    'Unexpected error ['
                                              || SQLCODE
                                              || '] on AXTA batch testing in HUM_XML.PROCESS_XMLDATA'
,            p_priority                    => 3
,            p_message_array               => l_message_array
,            p_attachment_name             => NULL
,            p_directory                   => NULL
,            p_filename                    => NULL
,            p_success                     => l_success
            );
         DBMS_XMLPARSER.freeparser (l_parser);
         DBMS_XMLDOM.freedocument (l_doc);
   END process_actotk_table;
END hum_xml;
/